unit UnitForm;

interface

uses
  Windows, Messages, SysUtils, Variants, Classes, Graphics, Controls, Forms,
  Dialogs, ComCtrls, StdCtrls, ExtCtrls, ShellAPI, Spin;

type
  TForm1 = class(TForm)
    ProgressBar1: TProgressBar;
    LabeledEditMtr: TLabeledEdit;
    ButtonSelMtr: TButton;
    LabeledEditInp: TLabeledEdit;
    ButtonSelCoo: TButton;
    LabeledEditOutCsv: TLabeledEdit;
    ButtonConvert: TButton;
    OpenDialog1: TOpenDialog;
    OpenDialog2: TOpenDialog;
    SpinEditMidx: TSpinEdit;
    LabelMidx: TLabel;
    CheckBoxUseReversed: TCheckBox;
    LabeledEditOutKmz: TLabeledEdit;
    ButtonConvToKmz: TButton;
    ButtonConvAndDrawGE: TButton;
    LabeledEditCooEnts: TLabeledEdit;
    ButtonSelCooEnts: TButton;
    Bevel1: TBevel;
    LabelNote: TLabel;
    procedure FormCreate(Sender: TObject);
    procedure ButtonSelMtrClick(Sender: TObject);
    procedure ButtonSelCooClick(Sender: TObject);
    procedure ButtonConvertClick(Sender: TObject);
    procedure ButtonConvToKmzClick(Sender: TObject);
    procedure ButtonConvAndDrawGEClick(Sender: TObject);
    procedure ButtonSelCooEntsClick(Sender: TObject);
  private
    { Private declarations }
    procedure WMCopyData(var Msg : TWMCopyData); message WM_COPYDATA;
  public
    { Public declarations }
  end;

var
  Form1: TForm1;

implementation

{$R *.dfm}

//------------------------------------------------------------------------------
procedure TForm1.WMCopyData(var Msg: TWMCopyData);
var MsgTxt: WideString;
    AnsiMsgTxt: AnsiString;
    ErrNo: integer;
begin
  SetString(MsgTxt, PWideChar(Msg.CopyDataStruct.lpData), Msg.CopyDataStruct.cbData);

  AnsiMsgTxt:= WideCharToString(PWideChar(MsgTxt));
  if AnsiMsgTxt = 'PROG_BAR_POS' then
    begin
      //Receives progress bar position value
      ProgressBar1.Position:= Msg.CopyDataStruct.dwData;
    end
  else
  if Msg.CopyDataStruct.dwData <> 0 then
    begin
      //Receives TransLT error
      SetLength(MsgTxt, Length(AnsiMsgTxt));
      ErrNo := Msg.CopyDataStruct.dwData;
      MessageBoxW(Self.Handle, PWideChar('ERROR (' + IntToStr(ErrNo) + '): ' + MsgTxt), 'Error', MB_OK);
      ProgressBar1.Position:= 0;
    end
  else
  if AnsiMsgTxt = 'CONV_DONE' then
    begin
      //Receives TransLT end message
      ShowMessage('TransLT conversion done.');
      ProgressBar1.Position:= 0;
    end;
end;

//------------------------------------------------------------------------------
procedure TForm1.FormCreate(Sender: TObject);
begin
  LabeledEditMtr.Text:= ExpandFileName(LabeledEditMtr.Text);
  LabeledEditInp.Text:= ExpandFileName(LabeledEditInp.Text);
  LabeledEditOutCsv.Text:= ChangeFileExt(LabeledEditInp.Text, '.csv');
  LabeledEditCooEnts.Text:= ExpandFileName(LabeledEditCooEnts.Text);
  LabeledEditOutKmz.Text:= ChangeFileExt(LabeledEditCooEnts.Text, '.kmz');
end;

//------------------------------------------------------------------------------
procedure TForm1.ButtonSelMtrClick(Sender: TObject);
begin
  OpenDialog1.InitialDir:= ExtractFileDir(LabeledEditMtr.Text);
  OpenDialog1.FileName  := ExtractFileName(LabeledEditMtr.Text);

  if OpenDialog1.Execute then
    begin
      LabeledEditMtr.Text:= OpenDialog1.FileName;
    end;
end;

//------------------------------------------------------------------------------
procedure TForm1.ButtonSelCooClick(Sender: TObject);
begin
  OpenDialog2.InitialDir:= ExtractFileDir(LabeledEditInp.Text);
  OpenDialog2.FileName  := ExtractFileName(LabeledEditInp.Text);

  if OpenDialog2.Execute then
    begin
      LabeledEditInp.Text:= OpenDialog2.FileName;

      if UpperCase(ExtractFileExt(OpenDialog2.FileName)) <>  '.CSV' then
        LabeledEditOutCsv.Text:= ChangeFileExt(OpenDialog2.FileName, '.csv')
      else
        LabeledEditOutCsv.Text:= ChangeFileExt(OpenDialog2.FileName, ' (1).csv');
    end;
end;

//------------------------------------------------------------------------------
procedure TForm1.ButtonSelCooEntsClick(Sender: TObject);
begin
  OpenDialog2.InitialDir:= ExtractFileDir(LabeledEditCooEnts.Text);
  OpenDialog2.FileName  := ExtractFileName(LabeledEditCooEnts.Text);

  if OpenDialog2.Execute then
    begin
      LabeledEditCooEnts.Text:= OpenDialog2.FileName;
      LabeledEditOutKmz.Text:= ChangeFileExt(LabeledEditInp.Text, '.kmz');
    end;
end;

//------------------------------------------------------------------------------
procedure TForm1.ButtonConvertClick(Sender: TObject);
var ParamStr: WideString;
begin
  ProgressBar1.Position:= 0;

  if (LabeledEditMtr.Text = '') or
     (LabeledEditInp.Text = '') or
     (LabeledEditOutCsv.Text = '') then
    begin
      ShowMessage('ERROR: One file missing!');
      Exit;
    end;

  ParamStr:= WideString(
    '"/F" '+                                //Parameter coomand for external use of TransLT ("/F" = convert coordinates file)
    '"'+LabeledEditMtr.Text+'" '+           //Transformation model file
    '"'+IntToStr(SpinEditMidx.Value)+'" '+  //Model index

    '"'+BoolToStr(CheckBoxUseReversed.Checked, True)[1]+'" '+
                                            //Use reversed transformation F = False, T = True
    '"'+LabeledEditInp.Text+'" '+           //Coordinate input file
    '"'+LabeledEditOutCsv.Text+'" '+        //Coordinate output file
    '"F" '+                                 //Show message error F = False, T = True
    '"'+IntToStr(Self.Handle)+'"');         //Handle of receiver application (This form)

  ShellExecuteW(Self.Handle, 'open', PWideChar(WideString('TransLT.exe')), PWideChar(ParamStr), nil, SW_SHOWNORMAL);
end;

//------------------------------------------------------------------------------
procedure TForm1.ButtonConvToKmzClick(Sender: TObject);
var ParamStr: WideString;
begin
  if (LabeledEditMtr.Text = '') or
     (LabeledEditInp.Text = '') or
     (LabeledEditOutKmz.Text = '') then
    begin
      ShowMessage('ERROR: One file missing!');
      Exit;
    end;

  ParamStr:= WideString(
    '"/D" '+                                //Parameter coomand for external use of TransLT ("/D" = convert coordinates file
                                            //  and save entities file or draw to Google Earth)
    '"'+LabeledEditMtr.Text+'" '+           //Transformation model file
    '"'+IntToStr(SpinEditMidx.Value)+'" '+  //Model index
    '"'+LabeledEditCooEnts.Text+'" '+       //Entities coordinate input file
    '"F" '+                                 //Select if the result file is edited or not F = False, T = True
    '"'+LabeledEditOutKmz.Text+'" '+        //Entities coordinate output file (csv, kml or kmz)
    '"F"');                                 //Delete input file F = False, T = True

  ShellExecuteW(Self.Handle, 'open', PWideChar(WideString('TransLT.exe')), PWideChar(ParamStr), nil, SW_SHOWNORMAL);
end;

//------------------------------------------------------------------------------
procedure TForm1.ButtonConvAndDrawGEClick(Sender: TObject);
var ParamStr: WideString;
begin
  if (LabeledEditMtr.Text = '') or
     (LabeledEditCooEnts.Text = '') then
    begin
      ShowMessage('ERROR: One file missing!');
      Exit;
    end;

  ParamStr:= WideString(
    '"/D" '+                                //Parameter coomand for external use of TransLT ("/D" = convert coordinates file
                                            //  and save entities file or draw to Google Earth)
    '"'+LabeledEditMtr.Text+'" '+           //Transformation model file
    '"'+IntToStr(SpinEditMidx.Value)+'" '+  //Model index
    '"'+LabeledEditCooEnts.Text+'" '+       //Entities coordinate input file
    '"F"');                                 //Select if the result file is edited or not F = False, T = True

  ShellExecuteW(Self.Handle, 'open', PWideChar(WideString('TransLT.exe')), PWideChar(ParamStr), nil, SW_SHOWNORMAL);
end;

end.


